#Section of the analysis for pyriproxyfen
library(patchwork)
library(MASS)
library(tidyverse)
library(readxl)
library(dplyr)
library(tidyr)
library(multcomp)
library(ggplot2)
library(tidyverse)
library(epiDisplay)
library(stats)
library(contrast)
library(emmeans)
library(DHARMa)

df1 <- read_excel("Pyriproxyfen_V1.1_JGJ_20210305.xlsx", 
                  col_types = c("text", "numeric", "numeric", 
                                "numeric", "numeric", "numeric", 
                                "numeric", "numeric", "date", "numeric", 
                                "text"))

#Analyzing the the count data of Adult emergence from the pyriproxyfen
#We need to add the total number of dead mosquitoes to the data frame

df1$Dose <- df1$Dose * 1000

df1$Dose <- as.factor(df1$Dose)

df2 <- filter(df1, HPE == 288 & Treatment ==	"Pyriproxyfen") # We are filtering the data since we only need to know what happened for the adult emergence for the pyriproxyfen

#Analyzing the data set using a Generalized Linear Model approach with a binomial distribution

m1 <- glm(cbind(Pupa_Dead, Adult) ~ Dose * Strain, family = binomial, data = df2)

car::Anova(m1, type ="III")

summary(m1)

#Visualization of the data diagnostics
m1Pyro <- simulateResiduals(fittedModel = m1, n = 250, plot = TRUE)

#Comparing the contrasts of Dose and Strain
emm1 <- emmeans(m3, ~Dose + Strain)

pairs(emm1)

emm1 <- emmeans(m1, specs = pairwise ~ Dose + Strain)

emm1contrasts <- emm1$contrasts %>% summary(infer=TRUE) %>% as.data.frame()

emm1contrasts #line 37 and 100

#Lets plot the data of the Adult emergence comparing them by Strain

#Lets plot this with a different perspective
df2$Mort <- (df2$Pupa_Dead/(df2$Pupa_Dead + df2$Adult)) *100

#Figure 1
#Default box plot
tiff("Fig1.tiff",width=8.0, height=3.0, units="in", res=300)

f <- ggplot(df2, aes(Dose, Mort, fill = Strain)) +
  geom_boxplot(color= "black",
               position = position_dodge())

print(f)

#Finished box plot
f + labs(x= "Pyriproxyfen dose (ppb)", y= expression(paste("Percentage of pupae mortality"))) +
  theme_classic() +
  scale_fill_manual(values = c('#999999','#E69F00'))


dev.off()
